@@ -1,5 +1,4 @@
-from .requests import (DaprRequest, delete, get, head, options, patch, post,
-                       put, request)
+from .requests import DaprRequest, delete, get, head, options, patch, post, put, request
 
 __all__ = [
     "DaprRequest",
