@@ -1,5 +1,5 @@
 from json import dumps, loads
-from typing import Optional
+from typing import Optional, Union
 from urllib.parse import urlparse
 from warnings import warn
 
@@ -43,7 +43,7 @@ class DaprRequest:
         http_method: Optional[str] = None,
         http_query_params: Optional[dict] = None,
         headers: Optional[dict] = None,
-        data: (dict or list or str or bytes) = None,
+        data: Union[dict,  list,  str,  bytes] = None,
         content_type: str = "application/json",
         metadata: Optional[dict] = None,
         is_grpc: Optional[bool] = False,
@@ -155,4 +155,4 @@ class DaprRequest:
         return self.resp.data
 
     def json(self):
-        return loads(self.byte)
+        return loads(self.bytes())
